@@ -3,7 +3,7 @@ Internal utilities
 */
 
 use {
-    anyhow::*,
+    anyhow::{ensure, Context, Result},
     colored::*,
     serde::de::DeserializeOwned,
     std::{fmt, fs, path::Path},
